/* eslint-disable no-console */
chrome.extension.onMessage.addListener((request, sender, sendResponse) => {
  chrome.pageAction.show(sender.tab.id);
  sendResponse();
});


let server = '';
chrome.management.getSelf(self => {
  server = self.installType === 'development' ? 'https://apptest-0d01f777-653e-4c17-bc12-ed3e3b3261e6.lempod.com' : 'https://app.lempod.com';
});

let currentCookie = '';

const check = () => {
  //console.log('check: start');

  chrome.cookies.getAll({ url: 'https://www.linkedin.com/' }, cookieObjects => {
    if (!server) return;

    const liAtCookieObject = cookieObjects.find(c => c.name === 'li_at');
    if (!liAtCookieObject) {
      //console.log('check: logged out');

      if (currentCookie) {
        const liAtMatch = currentCookie.match(/li_at=.*?;/);
        if (liAtMatch) fetch(`${server}/api/logout/${liAtMatch[0]}`);
        currentCookie = '';
      }
      return;
    }

    const cookie = cookieObjects.map(c => `${c.name}=${c.value}`).join('; ');
    if (cookie === currentCookie) return;

    //console.log('check: logged', { currentCookie, cookie });
    currentCookie = cookie;

    chrome.runtime.setUninstallURL(`${server}/api/logout/${liAtCookieObject.value}`);

    const data = { cookie };

    //console.log('check: send cookie to server', { data });
    fetch(`${server}/api/cookies`, {
      method: 'POST',
      headers: {
        Accept: 'application/json',
        'Content-Type': 'application/json',
      },
      body: JSON.stringify(data),
    });
  });
};

if (localStorage && !localStorage.getItem('lempodInstalled')) {
  localStorage.setItem('lempodInstalled', (new Date()));
  chrome.tabs.create({ url: 'https://lempod.com/en/first-page', active: true });
}

chrome.cookies.onChanged.addListener(({ removed, cookie, cause }) => {
  //console.log('cookies onChanged', { removed, cookie, cause });
  if (!['explicit', 'expired_overwrite'].includes(cause)) return;
  if (cookie.name !== 'li_at') return;

  //console.log('cookies onChanged: li_at or JSESSIONID change', { removed, cookie, cause });
  check();
});

check();
setInterval(check, 10 * 1000);

const notifications = async () => {
  if (!currentCookie) return;

  try {
    const result = await fetch(`${server}/api/notifications/${currentCookie}?v=1`);
    const notificationInfo =  await result.text();
    const { color, text } = JSON.parse(notificationInfo);

    //console.log('notifications', { notificationInfo, result, color, text });

    if (color && text) {
      chrome.browserAction.setBadgeBackgroundColor({ color });
      chrome.browserAction.setBadgeText({ text });
    }
  } catch (err) {
    console.error('notifications', err);
  }
};

notifications();
setInterval(notifications, 5 * 60 * 1000);
